@@ -645,8 +645,8 @@ void default_keybindings()
    add_binding(XK_G, XCF_Pin_Global);
    add_binding(XK_I, XCF_Info_Label);
    add_binding(ALT | XK_w, XCF_Connectivity);
-   add_binding(ALT | XK_s, XCF_Sim);
-   add_binding(SHIFT | ALT | XK_S, XCF_SPICE);
+   add_binding(ALT | XK_d, XCF_Sim);
+   add_binding(ALT | XK_a, XCF_SPICE);
    add_binding(ALT | XK_f, XCF_SPICEflat);
    add_binding(ALT | XK_p, XCF_PCB);
 #endif
