@@ -38,6 +38,7 @@ option add *output*font -*-times-bold-r-normal--14-*
 option add *output*txt*font -*-courier-bold-r-normal--14-*
 
 option add *output.textent.butp.psmenu*background beige
+option add *output.textent.txtf.sizb.sizemenu*background beige
 option add *output.textent.buto.orientmenu*background beige
 
 option add *help*activeBackground brown4
@@ -150,12 +151,12 @@ proc xcircuit::setpstype {mode} {
       {eps} { .output.textent.butp configure -text "Embedded (EPS)"
 	 grid remove .output.textent.but7
 	 grid remove .output.textent.butf
-	 grid remove .output.textent.txtp
+	 grid remove .output.textent.txtf
       }
       {full} {.output.textent.butp configure -text "Full Page"
 	 grid .output.textent.but7 -row 6 -column 3 -pady 5 -ipadx 10
 	 grid .output.textent.butf -row 5 -column 2 -padx 10
-	 grid .output.textent.txtp -row 6 -column 2 -sticky ew -padx 10
+	 grid .output.textent.txtf -row 6 -column 2 -sticky ew -padx 10
       }
    }
    ::set pstype $mode
@@ -194,10 +195,14 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	  .output.textent.txt4 delete 0 end
 	  ::set tcl_precision 3
 	  .output.textent.txt4 insert 0 [xcircuit::page width]
+	  .output.textent.txt4 insert end " "
+	  .output.textent.txt4 insert end [xcircuit::coordstyle get]
 	  .output.textent.txt5 delete 0 end
 	  .output.textent.txt5 insert 0 [xcircuit::page height]
-	  .output.textent.txtp delete 0 end
-	  .output.textent.txtp insert 0 [xcircuit::page size]
+	  .output.textent.txt5 insert end " "
+	  .output.textent.txt5 insert end [xcircuit::coordstyle get]
+	  .output.textent.txtf.txtp delete 0 end
+	  .output.textent.txtf.txtp insert 0 [xcircuit::page size]
 	  ::set tcl_precision $oldp
 	  xcircuit::setpstype [xcircuit::page encapsulation]
 	  ::set orient [xcircuit::page orientation]
@@ -292,6 +297,50 @@ proc xcircuit::setsymschem {} {
    }
 }
    
+#----------------------------------------------------------------------
+# Set the coordinate style to inches from cm and vice versa.
+# This routine avoids switching from fractional to decimal inches
+# and vice versa if we are already in one of the two inches modes.
+#
+# with no argument, or argument "get", returns the "short" name
+# ("cm" or "in") of the style.
+#----------------------------------------------------------------------
+
+proc xcircuit::coordstyle { { mode get } } {
+   set curstyle [xcircuit::config coordstyle]
+   switch -- $mode {
+      inches {
+	 switch -- $curstyle {
+	    centimeters {
+	       xcircuit::config coordstyle "decimal inches"
+	       xcircuit::pageupdate
+	    }
+	 }
+      }
+      centimeters -
+      cm {
+	 switch -- $curstyle {
+	    centimeters {
+	    }
+	    default {
+	       xcircuit::config coordstyle "centimeters"
+	       xcircuit::pageupdate
+	    }
+	 }
+      }
+      get {
+	 switch -- $curstyle {
+	    centimeters {
+	       return "cm"
+	    }
+	    default {
+	       return "in"
+	    }
+	 }
+      }
+   }
+}
+
 #----------------------------------------------------------------------
 # Command tags---these let the command-line entry functions update the
 # Tk windows, so that the Tk window structure doesn't need to be hard-
@@ -397,8 +446,8 @@ pack .output.title.field -side left
 tklabel .output.textent.lab1 -text "Filename:" -bg beige
 tklabel .output.textent.lab2 -text "Page label:" -bg beige
 tklabel .output.textent.lab3 -text "Scale:" -bg beige
-tklabel .output.textent.lab4 -text "X Size (in):" -bg beige
-tklabel .output.textent.lab5 -text "Y Size (in):" -bg beige
+tklabel .output.textent.lab4 -text "Width:" -bg beige
+tklabel .output.textent.lab5 -text "Height:" -bg beige
 tklabel .output.textent.lab6 -text "Orientation:" -bg beige
 tklabel .output.textent.lab7 -text "Mode:" -bg beige
 
@@ -415,7 +464,13 @@ menubutton .output.textent.butp -text "Embedded (EPS)" -bg beige \
 
 checkbutton .output.textent.butf -text "Auto-fit" -bg beige -variable autofit \
 	-onvalue true -offvalue false -command {xcircuit::page fit $autofit}
-entry .output.textent.txtp -bg white -relief sunken -width 14
+frame .output.textent.txtf
+menubutton .output.textent.txtf.sizb -text "Sizes" -bg beige \
+	-menu .output.textent.txtf.sizb.sizemenu
+entry .output.textent.txtf.txtp -bg white -relief sunken -width 14
+
+pack .output.textent.txtf.txtp -side left -fill y
+pack .output.textent.txtf.sizb -side left
 
 button .output.textent.but1 -text Apply -bg beige \
 	-command {xcircuit::page filename [.output.textent.txt1 get];\
@@ -433,7 +488,7 @@ button .output.textent.but5 -text Apply -bg beige \
 	-command {xcircuit::page height [.output.textent.txt5 get];\
 	.output.textent.but5 configure -text Okay}
 button .output.textent.but7 -text Apply -bg beige \
-	-command {xcircuit::page size [.output.textent.txtp get];\
+	-command {xcircuit::page size [.output.textent.txtf.txtp get];\
 	.output.textent.but7 configure -text Okay}
 
 bind .output.textent.txt1 <Return> {.output.textent.but1 invoke}
@@ -490,6 +545,36 @@ $m add radio -label "Full Page" -variable pstype -value full -command \
 pack .output.bbar.okay -side left -ipadx 10
 pack .output.bbar.cancel -side right -ipadx 10
 
+set m [menu .output.textent.txtf.sizb.sizemenu -tearoff 0]
+$m add radio -label "Letter" -variable sheetsize -value letter -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "8.5 x 11.0 in"}
+$m add radio -label "Legal" -variable sheetsize -value legal -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "8.5 x 14.0 in"}
+$m add radio -label "Statement" -variable sheetsize -value statement -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "5.5 x 8.5 in"}
+$m add radio -label "Tabloid" -variable sheetsize -value tabloid -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "11.0 x 17.0 in"}
+$m add radio -label "Ledger" -variable sheetsize -value ledger -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "17.0 x 11.0 in"}
+$m add radio -label "Folio" -variable sheetsize -value folio -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "8.5 x 13.0 in"}
+$m add radio -label "Quarto" -variable sheetsize -value quarto -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "8.472 x 10.833 in"}
+$m add radio -label "10x14" -variable sheetsize -value tenfourteen -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "10.0 x 14.0 in"}
+$m add radio -label "Executive" -variable sheetsize -value executive -command \
+	{ xcircuit::coordstyle inches; xcircuit::page size "7.5 x 10.0 in"}
+$m add radio -label "A3" -variable sheetsize -value a3 -command \
+	{ xcircuit::coordstyle centimeters; xcircuit::page size "30 x 42 cm"}
+$m add radio -label "A4" -variable sheetsize -value a4 -command \
+	{ xcircuit::coordstyle centimeters; xcircuit::page size "21 x 30 cm"}
+$m add radio -label "A5" -variable sheetsize -value a5 -command \
+	{ xcircuit::coordstyle centimeters; xcircuit::page size "14.82 x 18.43 cm"}
+$m add radio -label "B4" -variable sheetsize -value a5 -command \
+	{ xcircuit::coordstyle centimeters; xcircuit::page size "25.7 x 36.4 cm"}
+$m add radio -label "B5" -variable sheetsize -value a5 -command \
+	{ xcircuit::coordstyle centimeters; xcircuit::page size "18.2 x 25.7 cm"}
+
 #--------------------------------------
 # Create the popup help window
 #--------------------------------------
@@ -748,8 +833,8 @@ proc xcircuit::promptloadlibrary {} {
 
 proc xcircuit::promptsavelib { libno } {
    .dialog.bbar.okay configure -command \
-	{xcircuit::library $libno save [.dialog.textent.txt get];\
-	 wm withdraw .dialog}
+	"xcircuit::library $libno save [.dialog.textent.txt get];\
+	 wm withdraw .dialog"
    .dialog.textent.title.field configure -text "Enter name for library:"
    wm deiconify .dialog
    focus .dialog.textent.txt
@@ -953,7 +1038,7 @@ proc xcircuit::createtoolbar {} {
 		[expr {[winfo rooty .xcircuit.mainframe.toolbar.bco] \
 		- [winfo height .colormenu] / 2}] } \
 	{tk_popup .bordermenu [expr {[winfo rootx \
-		.xcircuit.mainframe.toolbar.toolbar.bbd] \
+		.xcircuit.mainframe.toolbar.bbd] \
 		- [winfo width .bordermenu]}] \
 		[expr {[winfo rooty .xcircuit.mainframe.toolbar.bbd] \
 		- [winfo height .bordermenu] / 2}] } \
@@ -1090,6 +1175,7 @@ set sel_poly true
 set sel_arc true
 set sel_spline true
 set sel_path true
+set sheetsize letter
 
 set m [menu .xcircuit.menubar.filebutton.filemenu -tearoff 0]
 $m add command -label "Read XCircuit File" -command {xcircuit::promptloadfile}
@@ -1479,6 +1565,7 @@ xcircuit::newlibrarybutton "User Library"
 bind .xcircuit.mainframe.mainarea.drawing <Enter> {focus %W}
 
 tkwait visibility .xcircuit.mainframe.mainarea.drawing
+focus .xcircuit.mainframe.mainarea.drawing
 
 # This pops down the interpreter window, if the "console.tcl" script was run.
 
