@@ -411,6 +411,7 @@ extern void toggle(xcWidget, Boolean *, caddr_t);
 extern void setcolorscheme(Boolean);
 extern void inversecolor(xcWidget, Boolean *, caddr_t);
 extern void togglegrid(u_short);
+extern float parseunits(char *);
 extern void setgridtype(char *);
 extern void getgridtype(xcWidget, pointertype, caddr_t);
 extern void newlibrary(xcWidget, caddr_t, caddr_t);
@@ -699,6 +700,7 @@ extern void writescalevalues(char *, char *, char *);
 extern int Tcl_GetHandleFromObj(Tcl_Interp *, Tcl_Obj *, void **);
 #else
 extern void updatetext(xcWidget, xcWidgetList, caddr_t);
+extern void delwin(xcWidget, popupstruct *, XClientMessageEvent *);
 #endif
 
 extern void makecursors();
